CONNECT Sys/quest AS SYSDBA

DECLARE
   PROCEDURE create_user (NAME_IN IN VARCHAR2)
   IS
      user_does_not_exist   EXCEPTION;
      PRAGMA EXCEPTION_INIT (user_does_not_exist, -01918);
   BEGIN
      /* Drop user if already exists */
      BEGIN
         EXECUTE IMMEDIATE 'drop user ' || NAME_IN || ' cascade';
      EXCEPTION
         WHEN user_does_not_exist
         THEN
            NULL;
      END;

      /* Grant required privileges...*/
      EXECUTE IMMEDIATE    '
    grant Create Session, Resource to '
                        || NAME_IN
                        || ' identified by '
                        || NAME_IN;
   END;
BEGIN
   create_user ('code_schema');
   create_user ('latvia');
   create_user ('eritrea');
END;
/

CONNECT code_schema/code_schema

CREATE TABLE app_code_table (n NUMBER)
/
INSERT INTO app_code_table
     VALUES (0)
/
COMMIT
/

CREATE OR REPLACE PROCEDURE app_code (n_in IN NUMBER)
AUTHID CURRENT_USER
IS
BEGIN
   DELETE FROM app_code_table
         WHERE n = n_in;
END;
/

GRANT EXECUTE ON app_code TO latvia
/
GRANT EXECUTE ON app_code TO eritrea
/
CONNECT latvia/latvia

CREATE TABLE app_code_table (n NUMBER)
/
INSERT INTO app_code_table
     VALUES (1)
/
COMMIT
/
CONNECT eritrea/eritrea

CREATE TABLE app_code_table (n NUMBER)
/
INSERT INTO app_code_table
     VALUES (2)
/
COMMIT
/
/*
Now build a test definition for app_code in the code_schema
and import it... 
*/

CONNECT code_schema/code_schema

@@q##app_code.qut

/*
Grant ability to execute this package to the country schemas
*/

GRANT EXECUTE ON q##app_code TO eritrea
/
GRANT EXECUTE ON q##app_code TO latvia
/

/* 

Use the my_codetester runtime customization package to tell
Code Tester to include the AUTHID CURRENT_USER clause in 
the test package specification.

*/

CREATE OR REPLACE PACKAGE my_codetester
/*
| Quest Code Tester for Oracle customization package
|
| The contents of this package are maintained by users of
| Quest Code Tester. Quest Software is not responsible for its
| contents or the impact of code placed in these programs.
|
| Overview: Use the my_codetester package to modify Quest Code Tester
|           behavior at certain key junctures as described below with
|           the defined stubs. Leave them NULL if you do not wish to
|           change the behavior. Check the Help doc for more details.
*/
IS
   /* 1.8.1

      Program: gen_pre_generation

   When executed: just before Code Tester generates a new test package.

   Purpose: allows users to alter generation behavior.

   This from accepts a schema name and package/program name.
   You can write code in the body of this program to selectively
   set generation options according to the program.

   DO NOT CHANGE THE HEADER OF THIS PROGRAM!!!
   */
   PROCEDURE gen_pre_generation (schema_in IN VARCHAR2, NAME_IN IN VARCHAR2);
END my_codetester;
/

CREATE OR REPLACE PACKAGE BODY my_codetester
IS
   PROCEDURE gen_pre_generation (schema_in IN VARCHAR2, NAME_IN IN VARCHAR2)
   IS
   BEGIN
      qu_generate.authid_current_user (add_in => TRUE);
   END gen_pre_generation;
END my_codetester;
/

/*

Now with the next generation of the test package, which should automatically
take place after the import, the test package will include AUTHID CURRENT_USER
and the test package can be run from any of the country schemas.

*/